==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSClassicLoadBalancerParametersBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AWSClassicLoadBalancerParametersBuilder extends AWSClassicLoadBalancerParametersFluentImpl<AWSClassicLoadBalancerParametersBuilder> implements VisitableBuilder<AWSClassicLoadBalancerParameters,AWSClassicLoadBalancerParametersBuilder>{
  public AWSClassicLoadBalancerParametersBuilder() {
    this(false);
  }
  public AWSClassicLoadBalancerParametersBuilder(Boolean validationEnabled) {
    this(new AWSClassicLoadBalancerParameters(), validationEnabled);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AWSClassicLoadBalancerParameters(), validationEnabled);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent,AWSClassicLoadBalancerParameters instance) {
    this(fluent, instance, false);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent,AWSClassicLoadBalancerParameters instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParameters instance) {
    this(instance,false);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParameters instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AWSClassicLoadBalancerParametersFluent<?> fluent;
  Boolean validationEnabled;
  public AWSClassicLoadBalancerParameters build() {
    AWSClassicLoadBalancerParameters buildable = new AWSClassicLoadBalancerParameters();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/AWSClassicLoadBalancerParametersBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AWSClassicLoadBalancerParametersBuilder extends AWSClassicLoadBalancerParametersFluent<AWSClassicLoadBalancerParametersBuilder> implements VisitableBuilder<AWSClassicLoadBalancerParameters,AWSClassicLoadBalancerParametersBuilder>{
  public AWSClassicLoadBalancerParametersBuilder() {
    this(false);
  }
  public AWSClassicLoadBalancerParametersBuilder(Boolean validationEnabled) {
    this(new AWSClassicLoadBalancerParameters(), validationEnabled);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AWSClassicLoadBalancerParameters(), validationEnabled);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent,AWSClassicLoadBalancerParameters instance) {
    this(fluent, instance, false);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParametersFluent<?> fluent,AWSClassicLoadBalancerParameters instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AWSClassicLoadBalancerParameters());

    if (instance != null) {
      fluent.withConnectionIdleTimeout(instance.getConnectionIdleTimeout());
      fluent.withConnectionIdleTimeout(instance.getConnectionIdleTimeout());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParameters instance) {
    this(instance,false);
  }
  public AWSClassicLoadBalancerParametersBuilder(AWSClassicLoadBalancerParameters instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AWSClassicLoadBalancerParameters());

    if (instance != null) {
      this.withConnectionIdleTimeout(instance.getConnectionIdleTimeout());
      this.withConnectionIdleTimeout(instance.getConnectionIdleTimeout());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AWSClassicLoadBalancerParametersFluent<?> fluent;
  Boolean validationEnabled;
  public AWSClassicLoadBalancerParameters build() {
    AWSClassicLoadBalancerParameters buildable = new AWSClassicLoadBalancerParameters(fluent.getConnectionIdleTimeout());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
